<?php

namespace Renfos\Timesheet\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Renfos\Timesheet\Interfaces\BoardRepositoryInterface;

class BoardPublicController extends BaseController
{
    // use BoardWorkflow;

    /**
     * Constructor.
     *
     * @param type \Renfos\Board\Interfaces\BoardRepositoryInterface $board
     *
     * @return type
     */
    public function __construct(BoardRepositoryInterface $board)
    {
        $this->repository = $board;
        parent::__construct();
    }

    /**
     * Show board's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $boards = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$timesheet::$board.names'))
            ->view('$timesheet::public.board.index')
            ->data(compact('$boards'))
            ->output();
    }

    /**
     * Show board's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $boards = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$timesheet::$board.names'))
            ->view('$timesheet::public.board.index')
            ->data(compact('$boards'))
            ->output();
    }

    /**
     * Show board.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $board = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$board->name . trans('$timesheet::$board.name'))
            ->view('$timesheet::public.board.show')
            ->data(compact('$board'))
            ->output();
    }

}
