<?php

namespace Renfos\Timesheet\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Renfos\Timesheet\Interfaces\ProjectRepositoryInterface;

class ProjectPublicController extends BaseController
{
    // use ProjectWorkflow;

    /**
     * Constructor.
     *
     * @param type \Renfos\Project\Interfaces\ProjectRepositoryInterface $project
     *
     * @return type
     */
    public function __construct(ProjectRepositoryInterface $project)
    {
        $this->repository = $project;
        parent::__construct();
    }

    /**
     * Show project's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $projects = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$timesheet::$project.names'))
            ->view('$timesheet::public.project.index')
            ->data(compact('$projects'))
            ->output();
    }

    /**
     * Show project's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $projects = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$timesheet::$project.names'))
            ->view('$timesheet::public.project.index')
            ->data(compact('$projects'))
            ->output();
    }

    /**
     * Show project.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $project = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$project->name . trans('$timesheet::$project.name'))
            ->view('$timesheet::public.project.show')
            ->data(compact('$project'))
            ->output();
    }

}
