<?php

namespace Renfos\Timesheet\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Renfos\Timesheet\Interfaces\TimesheetRepositoryInterface;

class TimesheetPublicController extends BaseController
{
    // use TimesheetWorkflow;

    /**
     * Constructor.
     *
     * @param type \Renfos\Timesheet\Interfaces\TimesheetRepositoryInterface $timesheet
     *
     * @return type
     */
    public function __construct(TimesheetRepositoryInterface $timesheet)
    {
        $this->repository = $timesheet;
        parent::__construct();
    }

    /**
     * Show timesheet's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $timesheets = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$timesheet::$timesheet.names'))
            ->view('$timesheet::public.timesheet.index')
            ->data(compact('$timesheets'))
            ->output();
    }

    /**
     * Show timesheet's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $timesheets = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$timesheet::$timesheet.names'))
            ->view('$timesheet::public.timesheet.index')
            ->data(compact('$timesheets'))
            ->output();
    }

    /**
     * Show timesheet.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $timesheet = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$timesheet->name . trans('$timesheet::$timesheet.name'))
            ->view('$timesheet::public.timesheet.show')
            ->data(compact('$timesheet'))
            ->output();
    }

}
