<?php

namespace Renfos\Timesheet\Policies;

use Litepie\User\Contracts\UserPolicy;
use Renfos\Timesheet\Models\Column;

class ColumnPolicy
{

    /**
     * Determine if the given user can view the column.
     *
     * @param UserPolicy $user
     * @param Column $column
     *
     * @return bool
     */
    public function view(UserPolicy $user, Column $column)
    {
        if ($user->canDo('timesheet.column.view') && $user->isAdmin()) {
            return true;
        }

        return $column->user_id == user_id() && $column->user_type == user_type();
    }

    /**
     * Determine if the given user can create a column.
     *
     * @param UserPolicy $user
     * @param Column $column
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('timesheet.column.create');
    }

    /**
     * Determine if the given user can update the given column.
     *
     * @param UserPolicy $user
     * @param Column $column
     *
     * @return bool
     */
    public function update(UserPolicy $user, Column $column)
    {
        if ($user->canDo('timesheet.column.edit') && $user->isAdmin()) {
            return true;
        }

        return $column->user_id == user_id() && $column->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given column.
     *
     * @param UserPolicy $user
     * @param Column $column
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Column $column)
    {
        return $column->user_id == user_id() && $column->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given column.
     *
     * @param UserPolicy $user
     * @param Column $column
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Column $column)
    {
        if ($user->canDo('timesheet.column.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given column.
     *
     * @param UserPolicy $user
     * @param Column $column
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Column $column)
    {
        if ($user->canDo('timesheet.column.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
