<?php

namespace Renfos\Timesheet\Policies;

use Litepie\User\Contracts\UserPolicy;
use Renfos\Timesheet\Models\ProjectUser;

class ProjectUserPolicy
{

    /**
     * Determine if the given user can view the project_user.
     *
     * @param UserPolicy $user
     * @param ProjectUser $project_user
     *
     * @return bool
     */
    public function view(UserPolicy $user, ProjectUser $project_user)
    {
        if ($user->canDo('timesheet.project_user.view') && $user->isAdmin()) {
            return true;
        }

        return $project_user->user_id == user_id() && $project_user->user_type == user_type();
    }

    /**
     * Determine if the given user can create a project_user.
     *
     * @param UserPolicy $user
     * @param ProjectUser $project_user
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('timesheet.project_user.create');
    }

    /**
     * Determine if the given user can update the given project_user.
     *
     * @param UserPolicy $user
     * @param ProjectUser $project_user
     *
     * @return bool
     */
    public function update(UserPolicy $user, ProjectUser $project_user)
    {
        if ($user->canDo('timesheet.project_user.edit') && $user->isAdmin()) {
            return true;
        }

        return $project_user->user_id == user_id() && $project_user->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given project_user.
     *
     * @param UserPolicy $user
     * @param ProjectUser $project_user
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ProjectUser $project_user)
    {
        return $project_user->user_id == user_id() && $project_user->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given project_user.
     *
     * @param UserPolicy $user
     * @param ProjectUser $project_user
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ProjectUser $project_user)
    {
        if ($user->canDo('timesheet.project_user.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given project_user.
     *
     * @param UserPolicy $user
     * @param ProjectUser $project_user
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ProjectUser $project_user)
    {
        if ($user->canDo('timesheet.project_user.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
