<?php

namespace Renfos\Timesheet\Policies;

use Litepie\User\Contracts\UserPolicy;
use Renfos\Timesheet\Models\Timesheet;

class TimesheetPolicy
{

    /**
     * Determine if the given user can view the timesheet.
     *
     * @param UserPolicy $user
     * @param Timesheet $timesheet
     *
     * @return bool
     */
    public function view(UserPolicy $user, Timesheet $timesheet)
    {
        if ($user->canDo('timesheet.timesheet.view') && $user->isAdmin()) {
            return true;
        }

        return $timesheet->user_id == user_id() && $timesheet->user_type == user_type();
    }

    /**
     * Determine if the given user can create a timesheet.
     *
     * @param UserPolicy $user
     * @param Timesheet $timesheet
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('timesheet.timesheet.create');
    }

    /**
     * Determine if the given user can update the given timesheet.
     *
     * @param UserPolicy $user
     * @param Timesheet $timesheet
     *
     * @return bool
     */
    public function update(UserPolicy $user, Timesheet $timesheet)
    {
        if ($user->canDo('timesheet.timesheet.edit') && $user->isAdmin()) {
            return true;
        }

        return $timesheet->user_id == user_id() && $timesheet->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given timesheet.
     *
     * @param UserPolicy $user
     * @param Timesheet $timesheet
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Timesheet $timesheet)
    {
        return $timesheet->user_id == user_id() && $timesheet->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given timesheet.
     *
     * @param UserPolicy $user
     * @param Timesheet $timesheet
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Timesheet $timesheet)
    {
        if ($user->canDo('timesheet.timesheet.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given timesheet.
     *
     * @param UserPolicy $user
     * @param Timesheet $timesheet
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Timesheet $timesheet)
    {
        if ($user->canDo('timesheet.timesheet.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
